==> templates-tooling-readme-generator-maven-plugin-2.0.5-sources.jar: org/mule/configuration/ConfigurationValidationProvider.java <==
package org.mule.configuration;

import com.google.common.base.Preconditions;
import org.apache.commons.lang.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * The class register all the section we require to validate
 *
 * @author damiansima
 */
public class ConfigurationValidationProvider {

    public static List<Placeholder> getPlaceholdersToValidate() {
        List<Placeholder> palceholdersToValidate = new ArrayList<Placeholder>();

        palceholdersToValidate.add(Placeholder.TEMPLATE_NAME);

        return palceholdersToValidate;
    }

    public static List<Section> getSectionsToValidate() {
        List<Section> sectionsToValidate = new ArrayList<Section>();
        sectionsToValidate.add(Section.USE_CASE);
        sectionsToValidate.add(Section.CONSIDERATIONS);
        sectionsToValidate.add(Section.RUN_IT);
        sectionsToValidate.add(Section.RUNNING_ON_PREMISE);
        sectionsToValidate.add(Section.WHERE_TO_DOWNLOAD_MULE_STUDIO_AND_MULE_ESB);
        sectionsToValidate.add(Section.IMPORTING_AN_ANYPOINT_TEMPLATE_INTO_STUDIO);
        sectionsToValidate.add(Section.RUNNING_ON_STUDIO);
        sectionsToValidate.add(Section.RUNNING_ON_STANDALONE);
        sectionsToValidate.add(Section.RUNNING_ON_CLOUDHUB);
        sectionsToValidate.add(Section.DEPLOYING_ON_PREMISE);
        sectionsToValidate.add(Section.APPLICATION_CONFIGURATION);
        sectionsToValidate.add(Section.API_CALLS);
        sectionsToValidate.add(Section.CUSTOMIZE_IT);
        sectionsToValidate.add(Section.CONFIG_XML);
        sectionsToValidate.add(Section.BUSINESS_LOGIC_XML);
        sectionsToValidate.add(Section.ENDPOINTS_XML);
        sectionsToValidate.add(Section.ERROR_HANDLING_XML);

        // System Dependant Sections
        sectionsToValidate.add(Section.DB_SRC);
        sectionsToValidate.add(Section.DB_DST);
        sectionsToValidate.add(Section.SAP_SRC);
        sectionsToValidate.add(Section.SAP_DST);
        sectionsToValidate.add(Section.SFDC_SRC);
        sectionsToValidate.add(Section.SFDC_DST);
        sectionsToValidate.add(Section.SIEB_SRC);
        sectionsToValidate.add(Section.SIEB_DST);
        sectionsToValidate.add(Section.SNOW_SRC);
        sectionsToValidate.add(Section.SNOW_DST);
        sectionsToValidate.add(Section.WDAY_SRC);
        sectionsToValidate.add(Section.WDAY_DST);
        sectionsToValidate.add(Section.JOBV_SRC);
        sectionsToValidate.add(Section.JOBV_DST);
        sectionsToValidate.add(Section.NETS_SRC);
        sectionsToValidate.add(Section.NETS_DST);
        sectionsToValidate.add(Section.MSDYN_SRC);
        sectionsToValidate.add(Section.MSDYN_DST);
        sectionsToValidate.add(Section.MSSP_SRC);
        sectionsToValidate.add(Section.MSSP_DST);
        sectionsToValidate.add(Section.WDAYF_SRC);
        sectionsToValidate.add(Section.WDAYF_DST);
        sectionsToValidate.add(Section.MKTO_SRC);
        sectionsToValidate.add(Section.MKTO_DST);

        sectionsToValidate.add(Section.DEFAULT_RUN_IT);
        sectionsToValidate.add(Section.DEFAULT_WHERE_TO_DOWNLOAD_MULE_STUDIO_AND_MULE_ESB);
        sectionsToValidate.add(Section.DEFAULT_IMPORTING_AN_ANYPOINT_TEMPLATE_INTO_STUDIO);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_PREMISE);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_STUDIO);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_STANDALONE);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_CLOUDHUB);
        sectionsToValidate.add(Section.DEFAULT_DEPLOYING_ON_CLOUDHUB);
        sectionsToValidate.add(Section.DEFAULT_PROPERTIES_TO_BE_CONFIGURED);
        sectionsToValidate.add(Section.DEFAULT_CUSTOMIZE_IT);
        sectionsToValidate.add(Section.DEFAULT_CONFIG_XML);
        sectionsToValidate.add(Section.DEFAULT_BUSINESS_LOGIC_XML);
        sectionsToValidate.add(Section.DEFAULT_ENDPOINTS_XML);
        sectionsToValidate.add(Section.DEFAULT_ERROR_HANDLING_XML);


        // Default System Dependant Sections
        sectionsToValidate.add(Section.DEFAULT_DB_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_DB_SRC);
        sectionsToValidate.add(Section.DEFAULT_DB_DST);
        sectionsToValidate.add(Section.DEFAULT_SAP_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SAP_SRC);
        sectionsToValidate.add(Section.DEFAULT_SAP_DST);
        sectionsToValidate.add(Section.DEFAULT_SFDC_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SFDC_SRC);
        sectionsToValidate.add(Section.DEFAULT_SFDC_DST);
        sectionsToValidate.add(Section.DEFAULT_SIEB_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SIEB_SRC);
        sectionsToValidate.add(Section.DEFAULT_SIEB_DST);
        sectionsToValidate.add(Section.DEFAULT_SNOW_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SNOW_SRC);
        sectionsToValidate.add(Section.DEFAULT_SNOW_DST);
        sectionsToValidate.add(Section.DEFAULT_WDAY_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_WDAY_SRC);
        sectionsToValidate.add(Section.DEFAULT_WDAY_DST);
        sectionsToValidate.add(Section.DEFAULT_JOBV_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_JOBV_SRC);
        sectionsToValidate.add(Section.DEFAULT_JOBV_DST);
        sectionsToValidate.add(Section.DEFAULT_NETS_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_NETS_SRC);
        sectionsToValidate.add(Section.DEFAULT_NETS_DST);
        sectionsToValidate.add(Section.DEFAULT_MSDYN_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_MSDYN_SRC);
        sectionsToValidate.add(Section.DEFAULT_MSDYN_DST);
        sectionsToValidate.add(Section.DEFAULT_MSSP_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_MSSP_SRC);
        sectionsToValidate.add(Section.DEFAULT_MSSP_DST);
        sectionsToValidate.add(Section.DEFAULT_WDAYF_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_WDAYF_SRC);
        sectionsToValidate.add(Section.DEFAULT_WDAYF_DST);
        sectionsToValidate.add(Section.DEFAULT_MKTO_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_MKTO_SRC);
        sectionsToValidate.add(Section.DEFAULT_MKTO_DST);


        return sectionsToValidate;
    }

    /**
     * It validates that a value is not null, empty, or contains just garbage values
     *
     * @param value the value to validate
     * @return the original value if it passed the validations
     */
    public static String validateConfigurationValue(String key, String value) {
        Preconditions.checkArgument(StringUtils.isNotEmpty(value), "The value can not be null nor empty. Configuration id: " + key);
        Preconditions.checkArgument(!value.trim().equals("."), "The value is mandatory don't be funny and type something of value. Configuration id:" + key);

        return value;
    }

}

==> templates-tooling-readme-generator-maven-plugin-2.0.9-sources.jar: org/mule/configuration/ConfigurationValidationProvider.java <==
package org.mule.configuration;

import com.google.common.base.Preconditions;
import org.apache.commons.lang.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * The class register all the section we require to validate
 *
 * @author damiansima
 */
public class ConfigurationValidationProvider {

    public static List<Placeholder> getPlaceholdersToValidate() {
        List<Placeholder> palceholdersToValidate = new ArrayList<Placeholder>();

        palceholdersToValidate.add(Placeholder.TEMPLATE_NAME);

        return palceholdersToValidate;
    }

    public static List<Section> getSectionsToValidate() {
        List<Section> sectionsToValidate = new ArrayList<Section>();
        sectionsToValidate.add(Section.USE_CASE);
        sectionsToValidate.add(Section.CONSIDERATIONS);
        sectionsToValidate.add(Section.RUN_IT);
        sectionsToValidate.add(Section.RUNNING_ON_PREMISE);
        sectionsToValidate.add(Section.WHERE_TO_DOWNLOAD_MULE_STUDIO_AND_MULE_ESB);
        sectionsToValidate.add(Section.IMPORTING_AN_ANYPOINT_TEMPLATE_INTO_STUDIO);
        sectionsToValidate.add(Section.RUNNING_ON_STUDIO);
        sectionsToValidate.add(Section.RUNNING_ON_STANDALONE);
        sectionsToValidate.add(Section.RUNNING_ON_CLOUDHUB);
        sectionsToValidate.add(Section.DEPLOYING_ON_PREMISE);
        sectionsToValidate.add(Section.APPLICATION_CONFIGURATION);
        sectionsToValidate.add(Section.API_CALLS);
        sectionsToValidate.add(Section.CUSTOMIZE_IT);
        sectionsToValidate.add(Section.CONFIG_XML);
        sectionsToValidate.add(Section.BUSINESS_LOGIC_XML);
        sectionsToValidate.add(Section.ENDPOINTS_XML);
        sectionsToValidate.add(Section.ERROR_HANDLING_XML);

        // System Dependant Sections
        sectionsToValidate.add(Section.DB_SRC);
        sectionsToValidate.add(Section.DB_DST);
        sectionsToValidate.add(Section.SAP_SRC);
        sectionsToValidate.add(Section.SAP_DST);
        sectionsToValidate.add(Section.SFDC_SRC);
        sectionsToValidate.add(Section.SFDC_DST);
        sectionsToValidate.add(Section.SIEB_SRC);
        sectionsToValidate.add(Section.SIEB_DST);
        sectionsToValidate.add(Section.SNOW_SRC);
        sectionsToValidate.add(Section.SNOW_DST);
        sectionsToValidate.add(Section.WDAY_SRC);
        sectionsToValidate.add(Section.WDAY_DST);
        sectionsToValidate.add(Section.JOBV_SRC);
        sectionsToValidate.add(Section.JOBV_DST);
        sectionsToValidate.add(Section.NETS_SRC);
        sectionsToValidate.add(Section.NETS_DST);
        sectionsToValidate.add(Section.MSDYN_SRC);
        sectionsToValidate.add(Section.MSDYN_DST);
        sectionsToValidate.add(Section.MSSP_SRC);
        sectionsToValidate.add(Section.MSSP_DST);
        sectionsToValidate.add(Section.WDAYF_SRC);
        sectionsToValidate.add(Section.WDAYF_DST);
        sectionsToValidate.add(Section.MKTO_SRC);
        sectionsToValidate.add(Section.MKTO_DST);
        sectionsToValidate.add(Section.S4HANA_SRC);
        sectionsToValidate.add(Section.S4HANA_DST);

        sectionsToValidate.add(Section.DEFAULT_RUN_IT);
        sectionsToValidate.add(Section.DEFAULT_WHERE_TO_DOWNLOAD_MULE_STUDIO_AND_MULE_ESB);
        sectionsToValidate.add(Section.DEFAULT_IMPORTING_AN_ANYPOINT_TEMPLATE_INTO_STUDIO);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_PREMISE);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_STUDIO);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_STANDALONE);
        sectionsToValidate.add(Section.DEFAULT_RUNNING_ON_CLOUDHUB);
        sectionsToValidate.add(Section.DEFAULT_DEPLOYING_ON_CLOUDHUB);
        sectionsToValidate.add(Section.DEFAULT_PROPERTIES_TO_BE_CONFIGURED);
        sectionsToValidate.add(Section.DEFAULT_CUSTOMIZE_IT);
        sectionsToValidate.add(Section.DEFAULT_CONFIG_XML);
        sectionsToValidate.add(Section.DEFAULT_BUSINESS_LOGIC_XML);
        sectionsToValidate.add(Section.DEFAULT_ENDPOINTS_XML);
        sectionsToValidate.add(Section.DEFAULT_ERROR_HANDLING_XML);


        // Default System Dependant Sections
        sectionsToValidate.add(Section.DEFAULT_DB_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_DB_SRC);
        sectionsToValidate.add(Section.DEFAULT_DB_DST);
        sectionsToValidate.add(Section.DEFAULT_SAP_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SAP_SRC);
        sectionsToValidate.add(Section.DEFAULT_SAP_DST);
        sectionsToValidate.add(Section.DEFAULT_SFDC_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SFDC_SRC);
        sectionsToValidate.add(Section.DEFAULT_SFDC_DST);
        sectionsToValidate.add(Section.DEFAULT_SIEB_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SIEB_SRC);
        sectionsToValidate.add(Section.DEFAULT_SIEB_DST);
        sectionsToValidate.add(Section.DEFAULT_SNOW_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_SNOW_SRC);
        sectionsToValidate.add(Section.DEFAULT_SNOW_DST);
        sectionsToValidate.add(Section.DEFAULT_WDAY_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_WDAY_SRC);
        sectionsToValidate.add(Section.DEFAULT_WDAY_DST);
        sectionsToValidate.add(Section.DEFAULT_JOBV_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_JOBV_SRC);
        sectionsToValidate.add(Section.DEFAULT_JOBV_DST);
        sectionsToValidate.add(Section.DEFAULT_NETS_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_NETS_SRC);
        sectionsToValidate.add(Section.DEFAULT_NETS_DST);
        sectionsToValidate.add(Section.DEFAULT_MSDYN_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_MSDYN_SRC);
        sectionsToValidate.add(Section.DEFAULT_MSDYN_DST);
        sectionsToValidate.add(Section.DEFAULT_MSSP_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_MSSP_SRC);
        sectionsToValidate.add(Section.DEFAULT_MSSP_DST);
        sectionsToValidate.add(Section.DEFAULT_WDAYF_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_WDAYF_SRC);
        sectionsToValidate.add(Section.DEFAULT_WDAYF_DST);
        sectionsToValidate.add(Section.DEFAULT_MKTO_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_MKTO_SRC);
        sectionsToValidate.add(Section.DEFAULT_MKTO_DST);
        sectionsToValidate.add(Section.DEFAULT_S4HANA_PRECONDITIONS);
        sectionsToValidate.add(Section.DEFAULT_S4HANA_SRC);
        sectionsToValidate.add(Section.DEFAULT_S4HANA_DST);


        return sectionsToValidate;
    }

    /**
     * It validates that a value is not null, empty, or contains just garbage values
     *
     * @param value the value to validate
     * @return the original value if it passed the validations
     */
    public static String validateConfigurationValue(String key, String value) {
        Preconditions.checkArgument(StringUtils.isNotEmpty(value), "The value can not be null nor empty. Configuration id: " + key);
        Preconditions.checkArgument(!value.trim().equals("."), "The value is mandatory don't be funny and type something of value. Configuration id:" + key);

        return value;
    }

}
